# Generated by Django 4.0.5 on 2022-07-03 13:04

from django.db import migrations
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):

    dependencies = [
        ('meta_prn', '0038_alter_endofstudy_delivery_date_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicaloffstudymedication',
            name='reason_other',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AddField(
            model_name='offstudymedication',
            name='reason_other',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...'),
        ),
    ]
