# Generated by Django 4.0.5 on 2022-06-30 11:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('meta_prn', '0035_auto_20220630_1140'),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='endofstudy',
            name='meta_prn_en_id_a50384_idx',
        ),
        migrations.RenameField(
            model_name='endofstudy',
            old_name='offschedule_datetime',
            new_name='offstudy_datetime',
        ),
        migrations.RenameField(
            model_name='endofstudy',
            old_name='offschedule_reason',
            new_name='offstudy_reason',
        ),
        migrations.RenameField(
            model_name='endofstudy',
            old_name='other_offschedule_reason',
            new_name='other_offstudy_reason',
        ),
        migrations.RenameField(
            model_name='historicalendofstudy',
            old_name='offschedule_datetime',
            new_name='offstudy_datetime',
        ),
        migrations.RenameField(
            model_name='historicalendofstudy',
            old_name='offschedule_reason',
            new_name='offstudy_reason',
        ),
        migrations.RenameField(
            model_name='historicalendofstudy',
            old_name='other_offschedule_reason',
            new_name='other_offstudy_reason',
        ),
    ]
