# Generated by Django 3.2.13 on 2022-07-04 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0052_alter_historicalscreeningpartone_p3_ltfu_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='historicalicpreferral',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical icp referral', 'verbose_name_plural': 'historical icp referrals'},
        ),
        migrations.AlterModelOptions(
            name='historicalscreeningpartone',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Subject Screening: Part One', 'verbose_name_plural': 'historical Subject Screening: Part One'},
        ),
        migrations.AlterModelOptions(
            name='historicalscreeningpartthree',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Subject Screening: Part Three', 'verbose_name_plural': 'historical Subject Screening: Part Three'},
        ),
        migrations.AlterModelOptions(
            name='historicalscreeningparttwo',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Subject Screening: Part Two', 'verbose_name_plural': 'historical Subject Screening: Part Two'},
        ),
        migrations.AlterModelOptions(
            name='historicalsubjectrefusal',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Subject Refusal', 'verbose_name_plural': 'historical Subject Refusals'},
        ),
        migrations.AlterModelOptions(
            name='historicalsubjectscreening',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Subject Screening', 'verbose_name_plural': 'historical Subject Screening'},
        ),
        migrations.AlterField(
            model_name='historicalicpreferral',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectrefusal',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
    ]
