# Generated by Django 3.2.13 on 2022-07-04 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_subject', '0120_alter_birthoutcomes_managers_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='historicalbirthoutcomes',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Birth Outcomes', 'verbose_name_plural': 'historical Birth Outcomes'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultsfbc',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: FBC', 'verbose_name_plural': 'historical Blood Results: FBC'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultsglu',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: Glucose', 'verbose_name_plural': 'historical Blood Results: Glucose'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultshba1c',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: HbA1c', 'verbose_name_plural': 'historical Blood Results: HbA1c'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultsins',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: Insulin', 'verbose_name_plural': 'historical Blood Results: Insulin'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultslft',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: LFT', 'verbose_name_plural': 'historical Blood Results: LFT'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultslipid',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: Lipids', 'verbose_name_plural': 'historical Blood Results: Lipids'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultsrft',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: RFT', 'verbose_name_plural': 'historical Blood Results: RFT'},
        ),
        migrations.AlterModelOptions(
            name='historicalcomplications',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Presence of Complications', 'verbose_name_plural': 'historical Presence of Complications'},
        ),
        migrations.AlterModelOptions(
            name='historicalcomplicationsglycemia',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Complications (Raised Glycemia)', 'verbose_name_plural': 'historical Complications (Raised Glycemia)'},
        ),
        migrations.AlterModelOptions(
            name='historicalconcomitantmedication',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Concomitant Medication', 'verbose_name_plural': 'historical Concomitant Medication'},
        ),
        migrations.AlterModelOptions(
            name='historicaldelivery',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Delivery', 'verbose_name_plural': 'historical Delivery'},
        ),
        migrations.AlterModelOptions(
            name='historicaldietandlifestyle',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Clinic follow up: Examination', 'verbose_name_plural': 'historical Clinic follow up: Examination'},
        ),
        migrations.AlterModelOptions(
            name='historicalegfrnotification',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical eGFR Notification', 'verbose_name_plural': 'historical eGFR Notifications'},
        ),
        migrations.AlterModelOptions(
            name='historicaleq5d3l',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical EuroQol EQ-5D-3L Instrument', 'verbose_name_plural': 'historical EuroQol EQ-5D-3L Instrument'},
        ),
        migrations.AlterModelOptions(
            name='historicalfollowupexamination',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Clinic follow up: Examination', 'verbose_name_plural': 'historical Clinic follow up: Examination'},
        ),
        migrations.AlterModelOptions(
            name='historicalfollowupvitals',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Clinic follow up: Vitals', 'verbose_name_plural': 'historical Clinic follow ups: Vitals'},
        ),
        migrations.AlterModelOptions(
            name='historicalglucose',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Glucose (IFG, OGTT)', 'verbose_name_plural': 'historical Glucose (IFG, OGTT)'},
        ),
        migrations.AlterModelOptions(
            name='historicalhealtheconomics',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Health Economics (M2)', 'verbose_name_plural': 'historical Health Economics (M2)'},
        ),
        migrations.AlterModelOptions(
            name='historicalhealtheconomicssimple',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Health Economics (M3)', 'verbose_name_plural': 'historical Health Economics (M3)'},
        ),
        migrations.AlterModelOptions(
            name='historicalhepatitistest',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Hepatitis Tests', 'verbose_name_plural': 'historical Hepatitis Tests'},
        ),
        migrations.AlterModelOptions(
            name='historicalmalariatest',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Malaria Test', 'verbose_name_plural': 'historical Malaria Tests'},
        ),
        migrations.AlterModelOptions(
            name='historicalmedicationadherence',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Medication Adherence', 'verbose_name_plural': 'historical Medication Adherence'},
        ),
        migrations.AlterModelOptions(
            name='historicalmnsi',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Michigan Neuropathy Screening Instrument (MNSI)', 'verbose_name_plural': 'historical Michigan Neuropathy Screening Instrument (MNSI)'},
        ),
        migrations.AlterModelOptions(
            name='historicalotherarvregimens',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Other ARV Regimens', 'verbose_name_plural': 'historical Other ARV Regimens'},
        ),
        migrations.AlterModelOptions(
            name='historicalotherarvregimensdetail',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Other ARV Regimens Detail', 'verbose_name_plural': 'historical Other ARV Regimens Detail'},
        ),
        migrations.AlterModelOptions(
            name='historicalpatienthistory',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Patient History', 'verbose_name_plural': 'historical Patient History'},
        ),
        migrations.AlterModelOptions(
            name='historicalphysicalexam',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Physical Exam', 'verbose_name_plural': 'historical Physical Exams'},
        ),
        migrations.AlterModelOptions(
            name='historicalpregnancyupdate',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Pregnancy Update', 'verbose_name_plural': 'historical Pregnancy Update'},
        ),
        migrations.AlterModelOptions(
            name='historicalsf12',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical SF-12 Health Survey', 'verbose_name_plural': 'historical SF-12 Health Survey'},
        ),
        migrations.AlterModelOptions(
            name='historicalstudymedication',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Study Medication', 'verbose_name_plural': 'historical Study Medication'},
        ),
        migrations.AlterModelOptions(
            name='historicalsubjectrequisition',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical subject requisition', 'verbose_name_plural': 'historical subject requisitions'},
        ),
        migrations.AlterModelOptions(
            name='historicalsubjectvisit',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical subject visit', 'verbose_name_plural': 'historical subject visits'},
        ),
        migrations.AlterModelOptions(
            name='historicalsubjectvisitmissed',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Missed Visit Report', 'verbose_name_plural': 'historical Missed Visit Report'},
        ),
        migrations.AlterModelOptions(
            name='historicalurinedipsticktest',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Urine Dipstick Test', 'verbose_name_plural': 'historical Urine Dipstick Tests'},
        ),
        migrations.AlterModelOptions(
            name='historicalurinepregnancy',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Urine Pregnancy', 'verbose_name_plural': 'historical Urine Pregnancys'},
        ),
        migrations.AddField(
            model_name='historicalmedicationadherence',
            name='pill_count_not_performed_reason',
            field=models.TextField(blank=True, null=True, verbose_name='Was a pill count performed'),
        ),
        migrations.AddField(
            model_name='medicationadherence',
            name='pill_count_not_performed_reason',
            field=models.TextField(blank=True, null=True, verbose_name='Was a pill count performed'),
        ),
        migrations.AlterField(
            model_name='historicalbirthoutcomes',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultsfbc',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultsglu',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultshba1c',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultsins',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultslft',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultslipid',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultsrft',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalcomplications',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalcomplicationsglycemia',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalconcomitantmedication',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicaldelivery',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicaldietandlifestyle',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalegfrnotification',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicaleq5d3l',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalfollowupexamination',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalfollowupvitals',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalhealtheconomics',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalhealtheconomicssimple',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalhepatitistest',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalmalariatest',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalmedicationadherence',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalmnsi',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalotherarvregimens',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalotherarvregimensdetail',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalpatienthistory',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalphysicalexam',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalpregnancyupdate',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalsf12',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalstudymedication',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectrequisition',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectvisit',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectvisitmissed',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalurinedipsticktest',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalurinepregnancy',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
    ]
