# Generated by Django 4.0.5 on 2022-06-25 18:56

from django.db import migrations, models
import django.db.models.deletion
import edc_model.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ('edc_protocol_violation', '0005_protocolincident_historicalprotocolincident_and_more'),
        ('meta_prn', '0025_alter_historicalprotocoldeviationviolation_options_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalprotocoldeviationviolation',
            name='violation_type',
        ),
        migrations.RemoveField(
            model_name='historicalprotocoldeviationviolation',
            name='violation_type_other',
        ),
        migrations.RemoveField(
            model_name='protocoldeviationviolation',
            name='violation_type',
        ),
        migrations.RemoveField(
            model_name='protocoldeviationviolation',
            name='violation_type_other',
        ),
        migrations.AlterField(
            model_name='historicalprotocoldeviationviolation',
            name='incident',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_protocol_violation.protocolviolations', verbose_name='Type of incident'),
        ),
        migrations.AlterField(
            model_name='historicalprotocoldeviationviolation',
            name='incident_datetime',
            field=models.DateTimeField(null=True, validators=[edc_model.validators.date.datetime_not_future], verbose_name='Date incident occurred'),
        ),
        migrations.AlterField(
            model_name='historicalprotocoldeviationviolation',
            name='incident_description',
            field=models.TextField(help_text='Describe in full. Explain how the incident happened, what occurred, etc.', null=True, verbose_name='Describe the incident'),
        ),
        migrations.AlterField(
            model_name='historicalprotocoldeviationviolation',
            name='incident_reason',
            field=models.TextField(null=True, verbose_name='Explain the reason why the incident occurred'),
        ),
        migrations.AlterField(
            model_name='protocoldeviationviolation',
            name='incident',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_protocol_violation.protocolviolations', verbose_name='Type of incident'),
        ),
        migrations.AlterField(
            model_name='protocoldeviationviolation',
            name='incident_datetime',
            field=models.DateTimeField(null=True, validators=[edc_model.validators.date.datetime_not_future], verbose_name='Date incident occurred'),
        ),
        migrations.AlterField(
            model_name='protocoldeviationviolation',
            name='incident_description',
            field=models.TextField(help_text='Describe in full. Explain how the incident happened, what occurred, etc.', null=True, verbose_name='Describe the incident'),
        ),
        migrations.AlterField(
            model_name='protocoldeviationviolation',
            name='incident_reason',
            field=models.TextField(null=True, verbose_name='Explain the reason why the incident occurred'),
        ),
    ]
