# Generated by Django 4.0.5 on 2022-06-28 11:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0049_historicalscreeningpartone_p3_ltfu_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='agree_to_p3',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable, subject is not eligible based on the criteria above')], default='Yes', max_length=15, verbose_name='Has the patient agreed to complete/return for the second stage of the screening?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='agree_to_p3',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable, subject is not eligible based on the criteria above')], default='Yes', max_length=15, verbose_name='Has the patient agreed to complete/return for the second stage of the screening?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='agree_to_p3',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable, subject is not eligible based on the criteria above')], default='Yes', max_length=15, verbose_name='Has the patient agreed to complete/return for the second stage of the screening?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='agree_to_p3',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable, subject is not eligible based on the criteria above')], default='Yes', max_length=15, verbose_name='Has the patient agreed to complete/return for the second stage of the screening?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='agree_to_p3',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable, subject is not eligible based on the criteria above')], default='Yes', max_length=15, verbose_name='Has the patient agreed to complete/return for the second stage of the screening?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='advised_to_fast',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the patient been advised to return FASTED for the second stage of the screening?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='p3_ltfu',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Undecided / Not applicable')], default='N/A', help_text='Only applicable if the subject missed the appointment for the second stage of screening. See above', max_length=15, verbose_name='Should additional attempts be made to contact this subject'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='p3_ltfu_comment',
            field=models.TextField(blank=True, null=True, verbose_name='Provide any additional comments on this decision (or leave blank)'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='p3_ltfu_date',
            field=models.DateField(blank=True, help_text='Must be after the appointment date for the second stage of screening (P3)', null=True, verbose_name='Date decision made'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='advised_to_fast',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the patient been advised to return FASTED for the second stage of the screening?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='p3_ltfu',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Undecided / Not applicable')], default='N/A', help_text='Only applicable if the subject missed the appointment for the second stage of screening. See above', max_length=15, verbose_name='Should additional attempts be made to contact this subject'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='p3_ltfu_comment',
            field=models.TextField(blank=True, null=True, verbose_name='Provide any additional comments on this decision (or leave blank)'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='p3_ltfu_date',
            field=models.DateField(blank=True, help_text='Must be after the appointment date for the second stage of screening (P3)', null=True, verbose_name='Date decision made'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='advised_to_fast',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the patient been advised to return FASTED for the second stage of the screening?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='p3_ltfu',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Undecided / Not applicable')], default='N/A', help_text='Only applicable if the subject missed the appointment for the second stage of screening. See above', max_length=15, verbose_name='Should additional attempts be made to contact this subject'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='p3_ltfu_comment',
            field=models.TextField(blank=True, null=True, verbose_name='Provide any additional comments on this decision (or leave blank)'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='p3_ltfu_date',
            field=models.DateField(blank=True, help_text='Must be after the appointment date for the second stage of screening (P3)', null=True, verbose_name='Date decision made'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='advised_to_fast',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the patient been advised to return FASTED for the second stage of the screening?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='p3_ltfu',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Undecided / Not applicable')], default='N/A', help_text='Only applicable if the subject missed the appointment for the second stage of screening. See above', max_length=15, verbose_name='Should additional attempts be made to contact this subject'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='p3_ltfu_comment',
            field=models.TextField(blank=True, null=True, verbose_name='Provide any additional comments on this decision (or leave blank)'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='p3_ltfu_date',
            field=models.DateField(blank=True, help_text='Must be after the appointment date for the second stage of screening (P3)', null=True, verbose_name='Date decision made'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='advised_to_fast',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the patient been advised to return FASTED for the second stage of the screening?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='p3_ltfu',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Undecided / Not applicable')], default='N/A', help_text='Only applicable if the subject missed the appointment for the second stage of screening. See above', max_length=15, verbose_name='Should additional attempts be made to contact this subject'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='p3_ltfu_comment',
            field=models.TextField(blank=True, null=True, verbose_name='Provide any additional comments on this decision (or leave blank)'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='p3_ltfu_date',
            field=models.DateField(blank=True, help_text='Must be after the appointment date for the second stage of screening (P3)', null=True, verbose_name='Date decision made'),
        ),
    ]
