# install editable repos
pip install -U Django==3.2.11
pip install argon2-cffi
pip install arrow
pip install boto3
pip install celery
pip install gunicorn
pip install inflect
pip install mysqlclient
pip install pyrabbit
pip install python-dateutil
pip install python-memcached
pip install pytz
pip install reportlab
pip uninstall sentry_sdk
pip install tqdm
pip install django-environ
pip install django-redis
pip install django-audit-fields
pip install django-celery-beat
pip install django-celery-results
pip install django-crypto-fields
pip install django-defender
pip install django-extensions
pip install django-logentry-admin
pip install django-multisite
pip install django-revision
pip install django-simple-history
pip install django-storages
pip install djangorestframework
pip install -e ../edc-action-item
pip install -e ../edc-adherence
pip install -e ../edc-adverse-event
pip install -e ../edc-appointment
pip install -e ../edc-auth
pip install -e ../edc-lab-results
pip install -e ../edc-consent
pip install -e ../edc-constants
pip install -e ../edc-crf
pip install -e ../edc-dashboard
pip install -e ../edc-data-manager
pip install -e ../edc-device
pip install -e ../edc-dx
pip install -e ../edc-dx-review
pip install -e ../edc-export
pip install -e ../edc-facility
pip install -e ../edc-fieldsets
pip install -e ../edc-form-describer
pip install -e ../edc-form-label
pip install -e ../edc-form-validators
pip install -e ../edc-glucose
pip install -e ../edc-identifier
pip install -e ../edc-lab
pip install -e ../edc-lab-dashboard
pip install -e ../edc-lab-panel
pip install -e ../edc-label
pip install -e ../edc-list-data
pip install -e ../edc-locator
pip install -e ../edc-ltfu
pip install -e ../edc-metadata
pip install -e ../edc-model
pip install -e ../edc-model-admin
pip install -e ../edc-model-fields
pip install -e ../edc-model-wrapper
pip install -e ../edc-navbar
pip install -e ../edc-notification
pip install -e ../edc-offstudy
pip install -e ../edc-pdutils
pip install -e ../edc-pharmacy
pip install -e ../edc-pharmacy-dashboard
pip install -e ../edc-prn
pip install -e ../edc-protocol
pip install -e ../edc-protocol-violation
pip install -e ../edc-randomization
pip install -e ../edc-reference
pip install -e ../edc-refusal
pip install -e ../edc-registration
pip install -e ../edc-reportable
pip install -e ../edc-reports
pip install -e ../edc-review-dashboard
pip install -e ../edc-screening
pip install -e ../edc-search
pip install -e ../edc-sites
pip install -e ../edc-subject-dashboard
pip install -e ../edc-subject-model-wrappers
pip install -e ../edc-timepoint
pip install -e ../edc-transfer
pip install -e ../edc-unblinding
pip install -e ../edc-utils
pip install -e ../edc-visit-schedule
pip install -e ../edc-visit-tracking
pip install -e ../edc-vitals
pip install -U Django==3.2.11
