# Generated by Django 3.2.13 on 2022-07-14 18:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_subject', '0122_auto_20220708_2144'),
    ]

    operations = [
        migrations.AddField(
            model_name='bloodresultsfbc',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultsfbc',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='bloodresultsglu',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultsglu',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='bloodresultshba1c',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultshba1c',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='bloodresultsins',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultsins',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='bloodresultslft',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultslft',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='bloodresultslipid',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultslipid',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='bloodresultsrft',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='bloodresultsrft',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsfbc',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsfbc',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsglu',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsglu',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultshba1c',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultshba1c',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsins',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsins',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultslft',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultslft',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultslipid',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultslipid',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsrft',
            name='missing',
            field=models.TextField(editable=False, help_text='calculated string of field names that have been left blank', null=True),
        ),
        migrations.AddField(
            model_name='historicalbloodresultsrft',
            name='missing_count',
            field=models.IntegerField(default=0, editable=False, help_text='A count of fields left blank'),
        ),
    ]
